.. _recipe_asr.emasses:

asr.emasses
===========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.emasses`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.emasses.main`
  - :py:func:`asr.emasses.refine`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.emasses@refine

or as a python module

.. code-block:: console

   $ python -m asr.emasses@refine

Detailed description
--------------------
Effective masses.

Steps
-----


asr.emasses
^^^^^^^^^^^
.. autofunction:: asr.emasses.main
   

asr.emasses@refine
^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.emasses.refine
   